InternalTestEndpoints class abstract interface

Internal test endpoints interface that contains implementation details that should only be used internally by the test tools.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

initialize(SerializationManagerServer serializationManager, EndpointDispatch endpoints) → void
Initializes the endpoints.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited