TestServerOutputMode enum

Options for controlling test server output during test execution.

Inheritance
Available extensions

Values

normal → const TestServerOutputMode

Default mode - only stderr is printed (stdout suppressed). This hides normal startup/shutdown logs while preserving error messages.

verbose → const TestServerOutputMode

All logging - both stdout and stderr are printed. Useful for debugging when you need to see all server output.

silent → const TestServerOutputMode

No logging - both stdout and stderr are suppressed. Completely silent mode, useful when you don't want any server output.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TestServerOutputMode>
A constant List of the values in this enum, in order of their declaration.