TestSessionBuilder class abstract

A test specific builder to create a Session that for instance can be used to call database methods. The builder can also be passed to endpoint calls. The builder will create a new session for each call.

Implementers

Constructors

TestSessionBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → Session
Given the properties set on the session through the copyWith method, this returns a serverpod Session that has the configured state.
copyWith({AuthenticationOverride? authentication, bool? enableLogging}) TestSessionBuilder
Creates a new unique session with the provided properties. This is useful for setting up different session states in the tests or simulating multiple users.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited