copyWith abstract method

TestSessionBuilder copyWith({
  1. AuthenticationOverride? authentication,
  2. bool? enableLogging,
})

Creates a new unique session with the provided properties. This is useful for setting up different session states in the tests or simulating multiple users.

Implementation

TestSessionBuilder copyWith({
  AuthenticationOverride? authentication,
  bool? enableLogging,
});