copyWith abstract method
Creates a new unique session with the provided properties. This is useful for setting up different session states in the tests or simulating multiple users.
Implementation
TestSessionBuilder copyWith({
AuthenticationOverride? authentication,
bool? enableLogging,
});